
# Slot: maximum_cardinality


the maximum number of entries for a multivalued slot

URI: [linkml:maximum_cardinality](https://w3id.org/linkml/maximum_cardinality)


## Domain and Range

None &#8594;  <sub>0..1</sub> [Integer](types/Integer.md)

## Parents

 *  is_a: [value_specification_constant](value_specification_constant.md)

## Children


## Used by

 * [AnonymousSlotExpression](AnonymousSlotExpression.md)
 * [SlotDefinition](SlotDefinition.md)
 * [SlotExpression](SlotExpression.md)
